@@ -1,10 +1,9 @@
-from typing import Dict
-
-import uuid
+import datetime
 import random
 import string
-import datetime
 import textwrap
+from typing import Dict
+import uuid
 
 from .constants import LIST_EMAIL_DOMAINS, LOREM_TEXT
 
@@ -43,10 +42,10 @@ class DataCreator:
             4: DataCreator.create_random_float(),
         }
         for index in range(3):
-            key = random.randint(1, 4)
-            value = random.randint(1, 4)
-            key = choices[key]
-            value = choices[value]
+            variable_key = random.randint(1, 4)
+            variable_value = random.randint(1, 4)
+            key = choices[variable_key]
+            value = choices[variable_value]
             random_dict[f"{key}"] = value
         return random_dict
 
@@ -77,12 +76,10 @@ class DataCreator:
     @staticmethod
     def create_random_uuid(kind: int = 4, **kwargs) -> uuid.UUID:
         uuids = {1: uuid.uuid1, 3: uuid.uuid3, 4: uuid.uuid4, 5: uuid.uuid5}
-        return uuids[kind](**kwargs)
+        return uuids[kind](**kwargs)  # type: ignore
 
     @staticmethod
-    def create_random_date(
-        day: int = None, month: int = None, year: int = None
-    ) -> datetime.date:
+    def create_random_date(day: int = None, month: int = None, year: int = None) -> datetime.date:
         month = month if month else random.randint(1, 12)
         if month == 2:
             max_day = 28
@@ -129,15 +126,11 @@ class DataCreator:
         return fnct(min_value, max_value)
 
     @staticmethod
-    def create_random_negative_integer(
-        min_value: int = 0, max_value: int = 10000000
-    ) -> int:
+    def create_random_negative_integer(min_value: int = 0, max_value: int = 10000000) -> int:
         return random.randint(min_value, max_value) * -1
 
     @staticmethod
-    def create_random_positive_integer(
-        min_value: int = 0, max_value: int = 10000000
-    ) -> int:
+    def create_random_positive_integer(min_value: int = 0, max_value: int = 10000000) -> int:
         return random.randint(min_value, max_value)
 
     @staticmethod
